@@ -1,6 +1,6 @@
 import napari
-from napari_serverkit._widget import ServerKitWidget
 from napari_serverkit import __version__
+from napari_serverkit.widgets import ServerKitWidget
 
 if __name__ == "__main__":
     viewer = napari.Viewer(title=f"Imaging Server Kit ({__version__})")
